@@ -77,7 +77,7 @@ class VM(BaseModel):
                                                            'vm_id': self.id})
 
     def console(self, enable):
-        request(self.oc_address, '/api/vm/console', {'token': self.token,
+        request(self.oc_address, '/api/vm/console/', {'token': self.token,
                                                      'vm_id': self.id,
                                                      'enable': enable})
 
